==> igniteui-react-charts-16.6.8.tgz: package/ES5/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var MoneyFlowIndexIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(MoneyFlowIndexIndicator, _super);
    function MoneyFlowIndexIndicator() {
        var _this = _super.call(this) || this;
        _this.pd = 1;
        return _this;
    }
    MoneyFlowIndexIndicator.prototype.get_p5 = function () {
        return new MoneyFlowIndexIndicatorStrategy();
    };
    Object.defineProperty(MoneyFlowIndexIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    MoneyFlowIndexIndicator.prototype.get_qi = function () {
        return MoneyFlowIndexIndicator.$;
    };
    Object.defineProperty(MoneyFlowIndexIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MoneyFlowIndexIndicator.prototype, "qq", {
        get: function () {
            return typeGetValue(this.c(MoneyFlowIndexIndicator.qr));
        },
        set: function (a) {
            this.h(MoneyFlowIndexIndicator.qr, a);
        },
        enumerable: true,
        configurable: true
    });
    MoneyFlowIndexIndicator.prototype.qb = function () {
        return this.qq;
    };
    MoneyFlowIndexIndicator.prototype.qk = function (a) {
        this.qq = a;
    };
    MoneyFlowIndexIndicator.$t = markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
    MoneyFlowIndexIndicator.qr = StrategyBasedIndicator.qn(14, MoneyFlowIndexIndicator.$);
    return MoneyFlowIndexIndicator;
}(StrategyBasedIndicator));
export { MoneyFlowIndexIndicator };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var MoneyFlowIndexIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(MoneyFlowIndexIndicator, _super);
    function MoneyFlowIndexIndicator() {
        var _this = _super.call(this) || this;
        _this.pk = 1;
        return _this;
    }
    MoneyFlowIndexIndicator.prototype.get_qc = function () {
        return new MoneyFlowIndexIndicatorStrategy();
    };
    Object.defineProperty(MoneyFlowIndexIndicator.prototype, "qc", {
        get: function () {
            return this.get_qc();
        },
        enumerable: true,
        configurable: true
    });
    MoneyFlowIndexIndicator.prototype.get_qp = function () {
        return MoneyFlowIndexIndicator.$;
    };
    Object.defineProperty(MoneyFlowIndexIndicator.prototype, "qp", {
        get: function () {
            return this.get_qp();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MoneyFlowIndexIndicator.prototype, "qx", {
        get: function () {
            return typeGetValue(this.c(MoneyFlowIndexIndicator.qy));
        },
        set: function (a) {
            this.h(MoneyFlowIndexIndicator.qy, a);
        },
        enumerable: true,
        configurable: true
    });
    MoneyFlowIndexIndicator.prototype.qi = function () {
        return this.qx;
    };
    MoneyFlowIndexIndicator.prototype.qr = function (a) {
        this.qx = a;
    };
    MoneyFlowIndexIndicator.$t = markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
    MoneyFlowIndexIndicator.qy = StrategyBasedIndicator.qu(14, MoneyFlowIndexIndicator.$);
    return MoneyFlowIndexIndicator;
}(StrategyBasedIndicator));
export { MoneyFlowIndexIndicator };
